@@ -1,14 +1,14 @@
 package Test::WWW::Mechanize::LibXML;
-$Test::WWW::Mechanize::LibXML::VERSION = '0.0.5';
+$Test::WWW::Mechanize::LibXML::VERSION = '0.0.6';
 use warnings;
 use strict;
 
-use 5.008;
+use 5.014;
 
 
 use parent 'Test::WWW::Mechanize';
 
-use HTML::TreeBuilder::LibXML;
+use HTML::TreeBuilder::LibXML ();
 
 use MRO::Compat;
 
@@ -34,7 +34,7 @@ sub _update_page
     my $ret = $self->maybe::next::method(@_);
 
     my $tree = HTML::TreeBuilder::LibXML->new;
-    $tree->parse($self->content());
+    $tree->parse( $self->content() );
     $tree->eof();
 
     $self->libxml_tree($tree);
@@ -47,13 +47,13 @@ sub contains_tag
 {
     local $Test::Builder::Level = $Test::Builder::Level + 1;
 
-    my $mech = shift;
+    my $mech     = shift;
     my $tag_spec = shift;
-    my $blurb = shift;
+    my $blurb    = shift;
 
     my $ret = $mech->libxml_tree->look_down(@$tag_spec);
 
-    ok($ret, $blurb);
+    ok( $ret, $blurb );
 
     return $ret;
 }
@@ -63,17 +63,17 @@ sub tree_matches_xpath
 {
     local $Test::Builder::Level = $Test::Builder::Level + 1;
 
-    my $mech = shift;
+    my $mech  = shift;
     my $xpath = shift;
     my $blurb = shift;
 
     my @nodes = $mech->libxml_tree->findnodes($xpath);
 
-    return ok(scalar(@nodes), $blurb);
+    return ok( scalar(@nodes), $blurb );
 }
 
 
-1; # End of Test::WWW::Mechanize::LibXML
+1;    # End of Test::WWW::Mechanize::LibXML
 
 __END__
 
@@ -88,7 +88,7 @@ web-sites.
 
 =head1 VERSION
 
-version 0.0.5
+version 0.0.6
 
 =head1 SYNOPSIS
 
@@ -108,10 +108,6 @@ This module inherits from L<Test::WWW::Mechanize>, and allows one to utilize
 L<HTML::TreeBuilder::LibXML> to perform XPath and L<HTML::TreeBuilder>
 queries on the tree.
 
-=head1 VERSION
-
-version 0.0.5
-
 =head1 METHODS
 
 =head2 $mech->libxml_tree()
@@ -132,40 +128,6 @@ it.
 
 Shlomi Fish, C<< <shlomif at insurgentsoftware.com> >>
 
-=head1 BUGS
-
-Please report any bugs or feature requests to C<bug-test-www-mechanize-libxml at rt.cpan.org>, or through
-the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Test-WWW-Mechanize-LibXML>.  I will be notified, and then you'll
-automatically be notified of progress on your bug as I make changes.
-
-=head1 SUPPORT
-
-You can find documentation for this module with the perldoc command.
-
-    perldoc Test::WWW::Mechanize::LibXML
-
-You can also look for information at:
-
-=over 4
-
-=item * RT: CPAN's request tracker
-
-L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=Test-WWW-Mechanize-LibXML>
-
-=item * AnnoCPAN: Annotated CPAN documentation
-
-L<http://annocpan.org/dist/Test-WWW-Mechanize-LibXML>
-
-=item * CPAN Ratings
-
-L<http://cpanratings.perl.org/d/Test-WWW-Mechanize-LibXML>
-
-=item * Search CPAN
-
-L<http://search.cpan.org/dist/Test-WWW-Mechanize-LibXML/>
-
-=back
-
 =head1 ACKNOWLEDGEMENTS
 
 Thanks to Insurgent Software for sponsoring this work.
@@ -180,7 +142,7 @@ be added as needed.
 Copyright 2010 Shlomi Fish. (C<shlomif@insurgentsoftware.com>,
 L<http://www.shlomifish.org/> )
 
-This program is distributed under the MIT (X11) License:
+This program is distributed under the MIT (Expat) License:
 L<http://www.opensource.org/licenses/mit-license.php>
 
 Permission is hereby granted, free of charge, to any person
@@ -204,37 +166,10 @@ WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
 OTHER DEALINGS IN THE SOFTWARE.
 
-=head1 AUTHOR
-
-Shlomi Fish <shlomif@insurgentsoftware.com>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is Copyright (c) 2018 by Shlomi Fish.
-
-This is free software, licensed under:
-
-  The MIT (X11) License
-
-=head1 BUGS
-
-Please report any bugs or feature requests on the bugtracker website
-L<https://github.com/shlomif/test-www-mechanize-libxml/issues>
-
-When submitting a bug or request, please include a test-file or a
-patch to an existing test-file that illustrates the bug or desired
-feature.
-
-=for :stopwords cpan testmatrix url annocpan anno bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
+=for :stopwords cpan testmatrix url bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
 
 =head1 SUPPORT
 
-=head2 Perldoc
-
-You can find documentation for this module with the perldoc command.
-
-  perldoc Test::WWW::Mechanize::LibXML
-
 =head2 Websites
 
 The following websites have more information about this module, and may be of help to you. As always,
@@ -252,14 +187,6 @@ L<https://metacpan.org/release/Test-WWW-Mechanize-LibXML>
 
 =item *
 
-Search CPAN
-
-The default CPAN search engine, useful to view POD in HTML format.
-
-L<http://search.cpan.org/dist/Test-WWW-Mechanize-LibXML>
-
-=item *
-
 RT: CPAN's Bug Tracker
 
 The RT ( Request Tracker ) website is the default bug/issue tracking system for CPAN.
@@ -268,22 +195,6 @@ L<https://rt.cpan.org/Public/Dist/Display.html?Name=Test-WWW-Mechanize-LibXML>
 
 =item *
 
-AnnoCPAN
-
-The AnnoCPAN is a website that allows community annotations of Perl module documentation.
-
-L<http://annocpan.org/dist/Test-WWW-Mechanize-LibXML>
-
-=item *
-
-CPAN Ratings
-
-The CPAN Ratings is a website that allows community ratings and reviews of Perl modules.
-
-L<http://cpanratings.perl.org/d/Test-WWW-Mechanize-LibXML>
-
-=item *
-
 CPANTS
 
 The CPANTS is a website that analyzes the Kwalitee ( code metrics ) of a distribution.
@@ -332,4 +243,25 @@ L<https://github.com/shlomif/test-www-mechanize-libxml>
 
   git clone https://github.com/shlomif/perl-Test-WWW-Mechanize-LibXML
 
+=head1 AUTHOR
+
+Shlomi Fish <shlomif@insurgentsoftware.com>
+
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website
+L<https://github.com/shlomif/test-www-mechanize-libxml/issues>
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2020 by Shlomi Fish.
+
+This is free software, licensed under:
+
+  The MIT (X11) License
+
 =cut
